@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2010-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2010-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -34,7 +34,7 @@ public:
 
 private:
     ResourceSettings();
-    virtual ~ResourceSettings();
+    ~ResourceSettings() override;
     static ResourceSettings *mSelf;
 };
 
