@@ -24,6 +24,7 @@
 #include <QSettings>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
+#include <QPluginLoader>
 
 #include <KAboutData>
 
@@ -37,18 +38,13 @@
 #include <QSettings>
 
 #include <private/protocol_p.h>
-#include <private/xdgbasedirs_p.h>
 #include <private/dbus_p.h>
 #include <private/instance_p.h>
-
-#if defined(HAVE_UNISTD_H) && !defined(Q_WS_WIN)
-#include <unistd.h>
-#else
-#define WIN32_LEAN_AND_MEAN
-#include <Windows.h>
-#endif
+#include <private/standarddirs_p.h>
 
 #include <iostream>
+#include <thread>
+#include <chrono>
 
 static bool startServer(bool verbose)
 {
@@ -103,21 +99,20 @@ static bool checkSearchSupportStatus()
     if (!pluginOverride.isEmpty()) {
         searchMethods << pluginOverride;
     } else {
-        const QStringList dirs = Akonadi::XdgBaseDirs::findPluginDirs();
+        const QStringList dirs = QCoreApplication::libraryPaths();
         for (const QString &pluginDir : dirs) {
-            QDir dir(pluginDir + QLatin1String("/akonadi"));
-            const QStringList desktopFiles = dir.entryList(QStringList() << QStringLiteral("*.desktop"), QDir::Files);
-            for (const QString &desktopFileName : desktopFiles) {
-                QSettings desktop(pluginDir + QLatin1String("/akonadi/") + desktopFileName, QSettings::IniFormat);
-                desktop.beginGroup(QStringLiteral("Desktop Entry"));
-                if (desktop.value(QStringLiteral("Type")).toString() != QLatin1String("AkonadiSearchPlugin")) {
+            QDir dir(pluginDir + QLatin1String("/akonadi/"));
+            const QStringList pluginFiles = dir.entryList(QDir::Files);
+            for (const QString &pluginFileName : pluginFiles) {
+                QPluginLoader loader(dir.absolutePath() + QLatin1Char('/') + pluginFileName);
+                const QVariantMap metadata = loader.metaData().value(QStringLiteral("MetaData")).toVariant().toMap();
+                if (metadata.value(QStringLiteral("X-Akonadi-PluginType")).toString() != QLatin1String("SearchPlugin")) {
                     continue;
                 }
-                if (!desktop.value(QStringLiteral("X-Akonadi-LoadByDefault"), true).toBool()) {
+                if (!metadata.value(QStringLiteral("X-Akonadi-LoadByDefault"), true).toBool()) {
                     continue;
                 }
-
-                searchMethods << desktop.value(QStringLiteral("Name")).toString();
+                searchMethods << metadata.value(QStringLiteral("X-Akonadi-PluginName")).toString();
             }
         }
     }
@@ -129,7 +124,7 @@ static bool checkSearchSupportStatus()
 
 static bool checkAvailableAgentTypes()
 {
-    const QStringList dirs = Akonadi::XdgBaseDirs::findAllResourceDirs("data", QStringLiteral("akonadi/agents"));
+    const auto dirs = Akonadi::StandardDirs::locateAllResourceDirs(QStringLiteral("akonadi/agents"));
     QStringList types;
     for (const QString &pluginDir : dirs) {
         QDir dir(pluginDir);
@@ -172,7 +167,11 @@ static void listInstances()
         bool running;
     };
     QVector<Instance> instances { { QStringLiteral("(default)"), instanceRunning() } };
-    const QDir instanceDir(Akonadi::XdgBaseDirs::saveDir("config", QStringLiteral("akonadi/instance")));
+#ifdef Q_OS_WIN
+    const QDir instanceDir(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QStringLiteral("/akonadi/config/instance"));
+#else
+    const QDir instanceDir(QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QStringLiteral("/akonadi/instance"));
+#endif
     if (instanceDir.exists()) {
         const auto list = instanceDir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
         for (const auto &e : list) {
@@ -274,11 +273,7 @@ int main(int argc, char **argv)
             return 4;
         } else {
             do {
-#if defined(HAVE_UNISTD_H) && !defined(Q_WS_WIN)
-                usleep(100000);
-#else
-                Sleep(100000);
-#endif
+                std::this_thread::sleep_for(std::chrono::milliseconds(100));
             } while (QDBusConnection::sessionBus().interface()->isServiceRegistered(Akonadi::DBus::serviceName(Akonadi::DBus::Control)));
             if (!startServer(verbose)) {
                 return 3;
