@@ -23,7 +23,7 @@
 #include "entitydeletedattribute.h"
 #include "item.h"
 #include "job_p.h"
-#include "helper_p.h"
+
 #include "trashsettings.h"
 
 #include <KLocalizedString>
@@ -226,7 +226,7 @@ void TrashRestoreJob::TrashRestoreJobPrivate::collectionsReceived(const Akonadi:
         return;
     }
 
-    //Explicit target Q_DECL_OVERRIDEs the resource/configured restore collection
+    //Explicit target overrides the resource/configured restore collection
     if (mTargetCollection.isValid()) {
         targetCollection = mTargetCollection;
     }
