@@ -76,6 +76,17 @@ void EntityOrderProxyModel::setOrderConfig(const KConfigGroup &configGroup)
     Q_EMIT layoutChanged();
 }
 
+// reimplemented in FavoriteCollectionOrderProxyModel
+Collection EntityOrderProxyModel::parentCollection(const QModelIndex &index) const
+{
+    return index.data(EntityTreeModel::ParentCollectionRole).value<Collection>();
+}
+
+static QString configKey(const Collection &col)
+{
+    return !col.isValid() ? QStringLiteral("0") : QString::number(col.id());
+}
+
 bool EntityOrderProxyModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
 {
     Q_D(const EntityOrderProxyModel);
@@ -83,9 +94,9 @@ bool EntityOrderProxyModel::lessThan(const QModelIndex &left, const QModelIndex
     if (!d->m_orderConfig.isValid()) {
         return KRecursiveFilterProxyModel::lessThan(left, right);
     }
-    Collection col = left.data(EntityTreeModel::ParentCollectionRole).value<Collection>();
+    const Collection col = parentCollection(left);
 
-    const QStringList list = d->m_orderConfig.readEntry(QString::number(col.id()), QStringList());
+    const QStringList list = d->m_orderConfig.readEntry(configKey(col), QStringList());
 
     if (list.isEmpty()) {
         return KRecursiveFilterProxyModel::lessThan(left, right);
@@ -104,6 +115,45 @@ bool EntityOrderProxyModel::lessThan(const QModelIndex &left, const QModelIndex
     return leftPosition < rightPosition;
 }
 
+QStringList EntityOrderProxyModel::configStringsForDroppedUrls(const QList<QUrl> &urls, const Akonadi::Collection &parentCol, bool *containsMove) const
+{
+    QStringList droppedList;
+    droppedList.reserve(urls.count());
+    for (const QUrl &url : urls) {
+        Collection col = Collection::fromUrl(url);
+
+        if (!col.isValid()) {
+            Item item = Item::fromUrl(url);
+            if (!item.isValid()) {
+                continue;
+            }
+
+            const QModelIndexList list = EntityTreeModel::modelIndexesForItem(this, item);
+            if (list.isEmpty()) {
+                continue;
+            }
+
+            if (!*containsMove && parentCollection(list.first()).id() != parentCol.id()) {
+                *containsMove = true;
+            }
+
+            droppedList << configString(list.first());
+        } else {
+            const QModelIndex idx = EntityTreeModel::modelIndexForCollection(this, col);
+            if (!idx.isValid()) {
+                continue;
+            }
+
+            if (!*containsMove && parentCollection(idx).id() != parentCol.id()) {
+                *containsMove = true;
+            }
+
+            droppedList << configString(idx);
+        }
+    }
+    return droppedList;
+}
+
 bool EntityOrderProxyModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent)
 {
     Q_D(EntityOrderProxyModel);
@@ -120,9 +170,11 @@ bool EntityOrderProxyModel::dropMimeData(const QMimeData *data, Qt::DropAction a
         return KRecursiveFilterProxyModel::dropMimeData(data, action, row, column, parent);
     }
 
-    bool containsMove = false;
 
     const QList<QUrl> urls = data->urls();
+    if (urls.isEmpty()) {
+        return false;
+    }
 
     Collection parentCol;
 
@@ -134,47 +186,24 @@ bool EntityOrderProxyModel::dropMimeData(const QMimeData *data, Qt::DropAction a
         }
 
         const QModelIndex targetIndex = index(0, column, parent);
-
-        parentCol = targetIndex.data(EntityTreeModel::ParentCollectionRole).value<Collection>();
+        parentCol = parentCollection(targetIndex);
     }
 
-    QStringList droppedList;
-    for (const QUrl &url : urls) {
-        Collection col = Collection::fromUrl(url);
 
-        if (!col.isValid()) {
-            Item item = Item::fromUrl(url);
-            if (!item.isValid()) {
-                continue;
-            }
+    bool containsMove = false;
+    QStringList droppedList = configStringsForDroppedUrls(urls, parentCol, &containsMove);
 
-            const QModelIndexList list = EntityTreeModel::modelIndexesForItem(this, item);
-            if (list.isEmpty()) {
-                continue;
-            }
-
-            if (!containsMove && list.first().data(EntityTreeModel::ParentCollectionRole).value<Collection>().id() != parentCol.id()) {
-                containsMove = true;
-            }
-
-            droppedList << configString(list.first());
-        } else {
-            const QModelIndex idx = EntityTreeModel::modelIndexForCollection(this, col);
-            if (!idx.isValid()) {
-                continue;
-            }
-
-            if (!containsMove && idx.data(EntityTreeModel::ParentCollectionRole).value<Collection>().id() != parentCol.id()) {
-                containsMove = true;
-            }
-
-            droppedList << configString(idx);
+    // Dropping new favorite folders
+    if (droppedList.isEmpty()) {
+        const bool ok = KRecursiveFilterProxyModel::dropMimeData(data, action, row, column, parent);
+        if (ok) {
+            droppedList = configStringsForDroppedUrls(urls, parentCol, &containsMove);
         }
     }
 
     QStringList existingList;
     if (d->m_orderConfig.hasKey(QString::number(parentCol.id()))) {
-        existingList = d->m_orderConfig.readEntry(QString::number(parentCol.id()), QStringList());
+        existingList = d->m_orderConfig.readEntry(configKey(parentCol), QStringList());
     } else {
         const int rowCount = this->rowCount(parent);
         existingList.reserve(rowCount);
@@ -192,7 +221,7 @@ bool EntityOrderProxyModel::dropMimeData(const QMimeData *data, Qt::DropAction a
         existingList.insert(row + i - (existingIndex > row ? 0 : 1), droppedList.at(i));
     }
 
-    d->m_orderConfig.writeEntry(QString::number(parentCol.id()), existingList);
+    d->m_orderConfig.writeEntry(configKey(parentCol), existingList);
 
     if (containsMove) {
         bool result = KRecursiveFilterProxyModel::dropMimeData(data, action, row, column, parent);
@@ -233,7 +262,7 @@ void EntityOrderProxyModelPrivate::saveOrder(const QModelIndex &parent)
     static const int column = 0;
     QModelIndex childIndex = q->index(0, column, parent);
 
-    QString parentKey = q->parentConfigString(childIndex);
+    const QString parentKey = q->parentConfigString(childIndex);
 
     if (parentKey.isEmpty()) {
         return;
@@ -243,7 +272,7 @@ void EntityOrderProxyModelPrivate::saveOrder(const QModelIndex &parent)
 
     list << q->configString(childIndex);
     saveOrder(childIndex);
-    list.reserve(rowCount);
+    list.reserve(list.count() + rowCount);
     for (int row = 1; row < rowCount; ++row) {
         childIndex = q->index(row, column, parent);
         list << q->configString(childIndex);
@@ -255,7 +284,7 @@ void EntityOrderProxyModelPrivate::saveOrder(const QModelIndex &parent)
 
 QString EntityOrderProxyModel::parentConfigString(const QModelIndex &index) const
 {
-    const Collection col = index.data(EntityTreeModel::ParentCollectionRole).value<Collection>();
+    const Collection col = parentCollection(index);
 
     Q_ASSERT(col.isValid());
     if (!col.isValid()) {
