@@ -48,9 +48,10 @@ namespace Server
  */
 class ColCopy : public Copy
 {
-    Q_OBJECT
 public:
-    bool parseStream() Q_DECL_OVERRIDE;
+    ~ColCopy() override = default;
+
+    bool parseStream() override;
 
 private:
     bool copyCollection(const Collection &source, const Collection &target);
