@@ -31,9 +31,9 @@ class Relation;
 
 class RelationStore : public Handler
 {
-    Q_OBJECT
-
 public:
+    ~RelationStore() override = default;
+
     bool parseStream() override;
 
 private:
