@@ -34,8 +34,9 @@ namespace Server
 */
 class SearchResult : public Handler
 {
-    Q_OBJECT
 public:
+    ~SearchResult() override = default;
+
     bool parseStream() override;
 
 private:
