@@ -21,6 +21,9 @@
 #include "akonadiserver_debug.h"
 #include "notificationmanager.h"
 #include "collectionreferencemanager.h"
+#include "aggregatedfetchscope.h"
+#include "storage/querybuilder.h"
+#include "utils.h"
 
 #include <QLocalSocket>
 #include <QDataStream>
@@ -51,6 +54,8 @@ NotificationSubscriber::NotificationSubscriber(NotificationManager *manager, qui
     : NotificationSubscriber(manager)
 {
     mSocket = new QLocalSocket(this);
+    connect(mSocket, &QLocalSocket::readyRead,
+            this, &NotificationSubscriber::handleIncomingData);
     connect(mSocket, &QLocalSocket::disconnected,
             this, &NotificationSubscriber::socketDisconnected);
     mSocket->setSocketDescriptor(socketDescriptor);
@@ -136,17 +141,29 @@ void NotificationSubscriber::disconnectSubscriber()
 {
     QMutexLocker locker(&mLock);
 
-    if (mManager) {
-        auto changeNtf = Protocol::SubscriptionChangeNotificationPtr::create();
-        changeNtf->setSubscriber(mSubscriber);
-        changeNtf->setSessionId(mSession);
-        changeNtf->setOperation(Protocol::SubscriptionChangeNotification::Remove);
-        mManager->slotNotify({ changeNtf });
-    }
+    auto changeNtf = Protocol::SubscriptionChangeNotificationPtr::create();
+    changeNtf->setSubscriber(mSubscriber);
+    changeNtf->setSessionId(mSession);
+    changeNtf->setOperation(Protocol::SubscriptionChangeNotification::Remove);
+    mManager->slotNotify({ changeNtf });
 
     disconnect(mSocket, &QLocalSocket::disconnected,
                this, &NotificationSubscriber::socketDisconnected);
     mSocket->close();
+
+    // Unregister ourselves from the aggergated collection fetch scope
+    auto cfs = mManager->collectionFetchScope();
+    if (mCollectionFetchScope.fetchIdOnly()) {
+        cfs->setFetchIdOnly(false);
+    }
+    if (mCollectionFetchScope.includeStatistics()) {
+        cfs->setFetchStatistics(false);
+    }
+    const auto attrs = mCollectionFetchScope.attributes();
+    for (const auto &attr : attrs) {
+        cfs->removeAttribute(attr);
+    }
+
     mManager->forgetSubscriber(this);
     deleteLater();
 }
@@ -159,13 +176,11 @@ void NotificationSubscriber::registerSubscriber(const Protocol::CreateSubscripti
     mSubscriber = command.subscriberName();
     mSession = command.session();
 
-    if (mManager) {
-        auto changeNtf = Protocol::SubscriptionChangeNotificationPtr::create();
-        changeNtf->setSubscriber(mSubscriber);
-        changeNtf->setSessionId(mSession);
-        changeNtf->setOperation(Protocol::SubscriptionChangeNotification::Add);
-        mManager->slotNotify({ changeNtf });
-    }
+    auto changeNtf = Protocol::SubscriptionChangeNotificationPtr::create();
+    changeNtf->setSubscriber(mSubscriber);
+    changeNtf->setSessionId(mSession);
+    changeNtf->setOperation(Protocol::SubscriptionChangeNotification::Add);
+    mManager->slotNotify({ changeNtf });
 }
 
 void NotificationSubscriber::modifySubscription(const Protocol::ModifySubscriptionCommand &command)
@@ -239,6 +254,21 @@ void NotificationSubscriber::modifySubscription(const Protocol::ModifySubscripti
     if (modifiedParts & Protocol::ModifySubscriptionCommand::ExclusiveFlag) {
         mExclusive = command.isExclusive();
     }
+    if (modifiedParts & Protocol::ModifySubscriptionCommand::ItemFetchScope) {
+        const auto newScope = command.itemFetchScope();
+        mManager->itemFetchScope()->apply(mItemFetchScope, newScope);
+        mItemFetchScope = newScope;
+    }
+    if (modifiedParts & Protocol::ModifySubscriptionCommand::CollectionFetchScope) {
+        const auto newScope = command.collectionFetchScope();
+        mManager->collectionFetchScope()->apply(mCollectionFetchScope, newScope);
+        mCollectionFetchScope = newScope;
+    }
+    if (modifiedParts & Protocol::ModifySubscriptionCommand::TagFetchScope) {
+        const auto newScope = command.tagFetchScope();
+        mManager->tagFetchScope()->apply(mTagFetchScope, newScope);
+        mTagFetchScope = newScope;
+    }
 
     if (mManager) {
         if (modifiedParts & Protocol::ModifySubscriptionCommand::Types) {
@@ -296,6 +326,8 @@ Protocol::SubscriptionChangeNotificationPtr NotificationSubscriber::toChangeNoti
     ntf->setIgnoredSessions(mIgnoredSessions);
     ntf->setAllMonitored(mAllMonitored);
     ntf->setExclusive(mExclusive);
+    ntf->setItemFetchScope(mItemFetchScope);
+    ntf->setCollectionFetchScope(mCollectionFetchScope);
     return ntf;
 }
 
@@ -369,8 +401,8 @@ bool NotificationSubscriber::acceptsItemNotification(const Protocol::ItemChangeN
                              || notificationForParentResource;
         TRACE_NTF("ACCEPTS ITEM: parent col referenced"
                   << "exclusive:" << mExclusive << ","
-                  << "parent monitored:" << isCollectionMonitored(notification.parentCollection()) << ","
-                  << "destination monitored:" << isMoveDestinationResourceMonitored(notification) << ","
+                  << "parent monitored:" << isCollectionMonitored(msg.parentCollection()) << ","
+                  << "destination monitored:" << isMoveDestinationResourceMonitored(msg) << ","
                   << "ntf for parent resource:" << notificationForParentResource << ":"
                   << "ACCEPTED:" << accepts);
         return accepts;
@@ -399,7 +431,7 @@ bool NotificationSubscriber::acceptsItemNotification(const Protocol::ItemChangeN
         }
 
         Q_FOREACH (const auto &item, msg.items()) {
-            if (isMimeTypeMonitored(item.mimeType)) {
+            if (isMimeTypeMonitored(item.mimeType())) {
                 TRACE_NTF("ACCEPTS ITEM: ACCEPTED - mimetype monitored");
                 return true;
             }
@@ -411,7 +443,7 @@ bool NotificationSubscriber::acceptsItemNotification(const Protocol::ItemChangeN
 
     // we explicitly monitor that item or the collections it's in
     Q_FOREACH (const auto &item, msg.items()) {
-        if (mMonitoredItems.contains(item.id)) {
+        if (mMonitoredItems.contains(item.id())) {
             TRACE_NTF("ACCEPTS ITEM: ACCEPTED: item explicitly monitored");
             return true;
         }
@@ -434,7 +466,8 @@ bool NotificationSubscriber::acceptsCollectionNotification(const Protocol::Colle
 {
     // Assumes mLock being locked by caller
 
-    if (msg.id() < 0) {
+    const auto &collection = msg.collection();
+    if (collection.id() < 0) {
         return false;
     }
 
@@ -451,12 +484,12 @@ bool NotificationSubscriber::acceptsCollectionNotification(const Protocol::Colle
         }
 
         //Deliver the notification if referenced from this session
-        if (CollectionReferenceManager::instance()->isReferenced(msg.id(), mSession)) {
+        if (CollectionReferenceManager::instance()->isReferenced(collection.id(), mSession)) {
             return true;
         }
 
         //Exclusive subscribers still want the notification
-        if (mExclusive && CollectionReferenceManager::instance()->isReferenced(msg.id())) {
+        if (mExclusive && CollectionReferenceManager::instance()->isReferenced(collection.id())) {
             return true;
         }
 
@@ -494,7 +527,7 @@ bool NotificationSubscriber::acceptsCollectionNotification(const Protocol::Colle
     }
 
     // we explicitly monitor that colleciton, or all of them
-    if (isCollectionMonitored(msg.id())) {
+    if (isCollectionMonitored(collection.id())) {
         return true;
     }
 
@@ -507,7 +540,7 @@ bool NotificationSubscriber::acceptsTagNotification(const Protocol::TagChangeNot
 {
     // Assumes mLock being locked by caller
 
-    if (msg.id() < 0) {
+    if (msg.tag().id() < 0) {
         return false;
     }
 
@@ -533,7 +566,6 @@ bool NotificationSubscriber::acceptsTagNotification(const Protocol::TagChangeNot
         if (!msg.resource().isEmpty() && !mIgnoredSessions.contains(msg.resource())) {
             return false;
         }
-
         // Now we got here, which means that this notification either has empty
         // resource, i.e. it is destined for a client applications, or it's
         // destined for resource that we *think* (see the hack above) this
@@ -554,11 +586,11 @@ bool NotificationSubscriber::acceptsTagNotification(const Protocol::TagChangeNot
         return true;
     }
 
-    if (mMonitoredTags.contains(msg.id())) {
+    if (mMonitoredTags.contains(msg.tag().id())) {
         return true;
     }
 
-    return false;
+    return true;
 }
 
 bool NotificationSubscriber::acceptsRelationNotification(const Protocol::RelationChangeNotification &msg) const
@@ -640,6 +672,20 @@ bool NotificationSubscriber::acceptsNotification(const Protocol::ChangeNotificat
     }
 }
 
+Protocol::CollectionChangeNotificationPtr NotificationSubscriber::customizeCollection(const Protocol::CollectionChangeNotificationPtr &ntf)
+{
+    const bool isReferencedFromSession = CollectionReferenceManager::instance()->isReferenced(ntf->collection().id(), mSession);
+    if (isReferencedFromSession != ntf->collection().referenced()) {
+        auto copy = Protocol::CollectionChangeNotificationPtr::create(*ntf);
+        auto copyCol = ntf->collection();
+        copyCol.setReferenced(isReferencedFromSession);
+        copy->setCollection(std::move(copyCol));
+        return copy;
+    }
+
+    return ntf;
+}
+
 bool NotificationSubscriber::notify(const Protocol::ChangeNotificationPtr &notification)
 {
     // Guard against this object being deleted while we are waiting for the lock
@@ -650,8 +696,12 @@ bool NotificationSubscriber::notify(const Protocol::ChangeNotificationPtr &notif
     }
 
     if (acceptsNotification(*notification)) {
+        auto ntf = notification;
+        if (ntf->type() == Protocol::Command::CollectionChangeNotification) {
+            ntf = customizeCollection(notification.staticCast<Protocol::CollectionChangeNotification>());
+        }
         QMetaObject::invokeMethod(this, "writeNotification", Qt::QueuedConnection,
-                                  Q_ARG(Akonadi::Protocol::ChangeNotificationPtr, notification));
+                                  Q_ARG(Akonadi::Protocol::ChangeNotificationPtr, ntf));
         return true;
     }
     return false;
