@@ -36,16 +36,15 @@ class Q_DECL_HIDDEN AgentTypeDialog::Private
 {
 public:
     Private(AgentTypeDialog *qq)
-        : Widget(nullptr),
-          q(qq)
+        : q(qq)
     {
 
     }
     void readConfig();
     void writeConfig();
-    AgentTypeWidget *Widget;
+    AgentTypeWidget *Widget = nullptr;
     AgentType agentType;
-    AgentTypeDialog *q;
+    AgentTypeDialog *q = nullptr;
 };
 
 void AgentTypeDialog::Private::writeConfig()
