@@ -48,7 +48,6 @@ class Q_DECL_HIDDEN CollectionView::Private
 public:
     Private(CollectionView *parent)
         : mParent(parent)
-        , xmlGuiClient(nullptr)
     {
     }
 
@@ -58,11 +57,11 @@ public:
     void itemCurrentChanged(const QModelIndex &index);
     bool hasParent(const QModelIndex &idx, Collection::Id parentId);
 
-    CollectionView *mParent;
+    CollectionView *mParent = nullptr;
     QModelIndex dragOverIndex;
     QTimer dragExpandTimer;
 
-    KXMLGUIClient *xmlGuiClient;
+    KXMLGUIClient *xmlGuiClient = nullptr;
 };
 
 void CollectionView::Private::init()
@@ -79,7 +78,7 @@ void CollectionView::Private::init()
     mParent->setDragEnabled(true);
 
     dragExpandTimer.setSingleShot(true);
-    mParent->connect(&dragExpandTimer, SIGNAL(timeout()), SLOT(dragExpand()));
+    mParent->connect(&dragExpandTimer, &QTimer::timeout, mParent, [this]() { dragExpand(); });
 
     mParent->connect(mParent, SIGNAL(clicked(QModelIndex)), mParent, SLOT(itemClicked(QModelIndex)));
 
@@ -184,7 +183,7 @@ void CollectionView::dragMoveEvent(QDragMoveEvent *event)
 
         const Collection collection = Collection::fromUrl(url);
         if (collection.isValid()) {
-            if (!supportedContentTypes.contains(QStringLiteral("inode/directory"))) {
+            if (!supportedContentTypes.contains(QLatin1String("inode/directory"))) {
                 break;
             }
 
